@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2001-2002 Mikael Hallendal <micke@codefactory.se>
+ * Copyright (C) 2001-2002 Mikael Hallendal <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@codefactory.se>
+ * Author: Mikael Hallendal <micke@imendio.com>
  */
 
 #ifdef HAVE_CONFIG_H
@@ -293,6 +293,12 @@ scrollkeeper_parse_toc_section (GNode       *parent,
 		return;
 	}
 
+	/* Restrict the sidebar to be two levels deep */
+	if (g_ascii_strncasecmp (xml_node->name, "tocsect1", 8) &&
+	    g_ascii_strncasecmp (xml_node->name, "tocsect2", 8)) {
+		return;
+	}
+
 	name = g_strdup (xml_str);
 	xmlFree (xml_str);
 	g_strstrip (name);
